.. _network_guide:

******************************
Ansible for Network Automation
******************************

Introduction
============

Ansible Network modules extend the benefits of simple, powerful, agentless automation to network administrators and teams. Ansible Network modules can configure your network stack, test and validate existing network state, and discover and correct network configuration drift.

If you're new to Ansible, or new to using Ansible for network management, start with the Getting Started Guide.

For documentation on using a particular network module, consult the :ref:`list of all network modules<network_modules>`. Some network modules are maintained by the Ansible community - here's a list of :ref:`network modules maintained by the Ansible Network Team<network_supported>`.

.. toctree::
   :maxdepth: 3
   :caption: Getting Started

   getting_started/index
   getting_started/basic_concepts
   getting_started/network_differences
   getting_started/first_playbook
   getting_started/first_inventory
   getting_started/intermediate_concepts




.. toctree::
   :maxdepth: 3
   :caption: User Guide

   user_guide/index
   user_guide/faq
   user_guide/network_best_practices_2.5
   user_guide/network_debug_troubleshooting
   user_guide/network_working_with_command_output
   user_guide/platform_index
